# Guanciale -- Carbonara Project

Grab informations needed by Carbonara from executables and disassemblers databases

## Install
### Linux
```
$ sudo apt install python python-pip
$ pip install -r requirements.txt
$ python setup.py install
```
### Windows
```
> python -m pip install -r requirements.txt
> python setup.py install
```


